@@ -344,6 +344,19 @@ class MACAddress(FieldType):
         raise ValueError(_LE("Malformed MAC %s"), value)
 
 
+class PCIAddress(FieldType):
+
+    _REGEX = re.compile(r'^[0-9a-f]{4}:[0-9a-f]{2}:[0-1][0-9a-f].[0-7]$')
+
+    @staticmethod
+    def coerce(obj, attr, value):
+        if isinstance(value, six.string_types):
+            newvalue = value.lower()
+            if PCIAddress._REGEX.match(newvalue):
+                return newvalue
+        raise ValueError(_LE("Malformed PCI address %s"), value)
+
+
 class Integer(FieldType):
     @staticmethod
     def coerce(obj, attr, value):
@@ -685,7 +698,7 @@ class BaseEnumField(AutoTypedField):
 
         if not isinstance(self.AUTO_TYPE, Enum):
             raise exception.EnumFieldInvalid(
-                typename=self.AUTO_TYPE.__class__.__name,
+                typename=self.AUTO_TYPE.__class__.__name__,
                 fieldname=self.__class__.__name__)
 
         super(BaseEnumField, self).__init__(**kwargs)
@@ -839,6 +852,10 @@ class MACAddressField(AutoTypedField):
     AUTO_TYPE = MACAddress()
 
 
+class PCIAddressField(AutoTypedField):
+    AUTO_TYPE = PCIAddress()
+
+
 class IntegerField(AutoTypedField):
     AUTO_TYPE = Integer()
 
